import os
import socket
import wolfssl

def run_client(file_path):
    # CA-Zertifikat laden
    ca_cert = "../certificates/ca-cert.pem"

    # Optionen für Verschlüsselungsalgorithmen
    print("Wählen Sie einen Verschlüsselungsalgorithmus:")
    print("1: AES 128 GCM (sicher)")
    print("3: ChaCha20-Poly1305 (sicher)")
    print("4: RC4 (unsicher)")
    print("5: 3DES (unsicher)")
    
    choice_cipher = input("Geben Sie die Nummer des gewünschten Verschlüsselungsalgorithmus ein: ")

    # Cipher Suite entsprechend der Wahl des Benutzers auswählen
    if choice_cipher == "1":
        cipher_suite = "TLS_AES_128_GCM_SHA256"  # AES 128 GCM (sicher)
    elif choice_cipher == "2":
        cipher_suite = "TLS_CHACHA20_POLY1305_SHA256"  # ChaCha20-Poly1305 (sicher)
    elif choice_cipher == "3":
        cipher_suite = "TLS_RSA_WITH_RC4_128_SHA"  # RC4 (unsicher)
    elif choice_cipher == "4":
        cipher_suite = "TLS_RSA_WITH_3DES_EDE_CBC_SHA"  # 3DES (unsicher)
    else:
        print("Ungültige Auswahl, Standard-AES 128 GCM wird verwendet.")
        cipher_suite = "TLS_AES_128_GCM_SHA256"

    # SSL-Kontext erstellen
    context = wolfssl.SSLContext(wolfssl.PROTOCOL_TLSv1_2)
    context.load_verify_locations(ca_cert)

    try:
        # Verschlüsselung (Cipher Suite) setzen
        context.set_ciphers(cipher_suite)
        print(f"Cipher Suite '{cipher_suite}' erfolgreich gesetzt!")
    except Exception as e:
        print(f"Fehler beim Setzen der Cipher Suite: {e}")
        print("Möglicherweise wird die angegebene Cipher Suite von wolfSSL nicht unterstützt.")
        return

    # Sichere Verbindung mit dem Server herstellen
    with socket.create_connection(("192.168.178.63", 5000)) as sock:
        with context.wrap_socket(sock, server_hostname="server") as ssl_sock:
            print("Mit dem Server verbunden!")

            # Datei senden
            with open(file_path, "rb") as f:
                while chunk := f.read(1024):
                    ssl_sock.sendall(chunk)
            print(f"Datei '{file_path}' erfolgreich an den Server gesendet.")

if __name__ == "__main__":
    # Dateipfad der zu übertragenden Datei
    file_to_send = "../testData/test.txt"

    # Stelle sicher, dass die Datei existiert
    if not os.path.exists(file_to_send):
        print(f"Die Datei '{file_to_send}' wurde nicht gefunden!")
    else:
        run_client(file_to_send)
