import socket
import wolfssl

def run_server():
    # Server-Zertifikat und Schlüssel
    cert_file = "../certificates/server-cert.pem"
    key_file = "../certificates/server-key.pem"

    # Optionen für Verschlüsselungsalgorithmen
    print("Wählen Sie einen Verschlüsselungsalgorithmus:")
    print("1: AES 128 GCM (sicher)")
    print("2: ChaCha20 Poly1305 (sicher)")
    print("3: RC4 (unsicher)")
    print("4: 3DES (unsicher)")
    choice_cipher = input("Geben Sie die Nummer des gewünschten Verschlüsselungsalgorithmus ein: ")

    # Cipher Suite entsprechend der Wahl des Benutzers auswählen
    if choice_cipher == "1":
        cipher_suite = "TLS_AES_128_GCM_SHA256"  # AES 128 GCM (sicher)
    elif choice_cipher == "2":
        cipher_suite = "TLS_CHACHA20_POLY1305_SHA256"  # ChaCha20 Poly1305 (sicher)
    elif choice_cipher == "3":
        cipher_suite = "TLS_RSA_WITH_RC4_128_SHA"  # RC4 (unsicher)
    elif choice_cipher == "4":
        cipher_suite = "TLS_RSA_WITH_3DES_EDE_CBC_SHA"  # 3DES (unsicher)
    else:
        print("Ungültige Auswahl, Standard-AES 128 GCM wird verwendet.")
        cipher_suite = "TLS_AES_128_GCM_SHA256"

    # SSL-Kontext erstellen (Standard: TLSv1.2, da keine Auswahl mehr)
    context = wolfssl.SSLContext(wolfssl.PROTOCOL_TLSv1_2)
    context.load_cert_chain(certfile=cert_file, keyfile=key_file)

    # Verschlüsselung (Cipher Suite) setzen
    context.set_ciphers(cipher_suite)

    # Server-Socket erstellen
    with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as sock:
        sock.bind(("0.0.0.0", 5000))  # Auf allen Schnittstellen lauschen
        sock.listen(5)
        print(f"Server läuft auf Port 5000 mit Cipher Suite: {cipher_suite}...")

        while True:
            # Verbindung akzeptieren
            client_sock, addr = sock.accept()
            print(f"Verbindung akzeptiert von {addr}!")

            try:
                # SSL/TLS-Schicht hinzufügen
                ssl_sock = context.wrap_socket(client_sock, server_side=True)

                # Datei empfangen
                with open("received_file.txt", "wb") as f:
                    while True:
                        data = ssl_sock.recv(1024)
                        if not data:
                            break
                        f.write(data)
                print("Datei erfolgreich empfangen und gespeichert als 'received_file.txt'")
            except Exception as e:
                print(f"Fehler bei der Verarbeitung der Verbindung: {e}")
            finally:
                ssl_sock.close()  # SSL-Socket explizit schließen
                client_sock.close()  # Basis-Socket explizit schließen

if __name__ == "__main__":
    run_server()
