# Create certificate folder
mkdir -p certificates
cd certificates

# Create a private key for CA (ca-key.pem)
echo "Creating private CA key ..."
openssl genrsa -out ca-key.pem 2048

# Create CA certificate (ca-cert.pem)
echo "Creating CA certificate ..."
openssl req -x509 -new -nodes -key ca-key.pem -sha256 -days 365 -out ca-cert.pem

# Create a private server key (server-key.pem)
echo "Creating private server key ..."
openssl genrsa -out server-key.pem 2048

# Create a CSR for the server (server.csr)
echo "Creating server CSR..."
openssl req -new -key server-key.pem -out server.csr

# Sign certificate with CA
echo "Signing certificate with CA..."
openssl x509 -req -in server.csr -CA ca-cert.pem -CAkey ca-key.pem -CAcreateserial -out server-cert.pem -days 365 -sha256

# Test the certificate
echo "Testing certificate..."
openssl verify -CAfile ca-cert.pem server-cert.pem