# Update package list
echo "Updating package list..."
sudo apt update

# Install dependencies
echo "Installing dependencies..."
sudo apt install -y build-essential cmake git

# Check if cmake and make are installed
echo "Checking for cmake and make..."
which cmake || { echo "cmake not found, installing..."; sudo apt install -y cmake; }
which make || { echo "make not found, installing..."; sudo apt install -y make; }

# Clone the WolfSSL repository
echo "Cloning WolfSSL repository..."
git clone https://github.com/wolfSSL/wolfssl.git

# Change to the wolfssl directory
cd wolfssl

# Create and change to the build directory
echo "Creating build directory..."
mkdir build
cd build

# Configure the build
echo "Configuring build with cmake..."
cmake ..

# Compile the source code
echo "Compiling the code..."
make

# Install the compiled binaries
echo "Installing WolfSSL..."
sudo make install

# Update library cache
echo "Updating library cache..."
sudo ldconfig

echo "WolfSSL installation completed"